==> datawidgets-0.0.9-py3-none-any.whl: datawidgets/dataset/stats_mixins.py <==
from datawidgets.imports import *
from datawidgets.utils import *
from datawidgets.data import *
from .image_dataset import *

from matplotlib.ticker import MaxNLocator


def compute_label_distribution(df: pd.DataFrame, label_col="label") -> pd.Series:
    "Computes the frequency of labels from a dataset's internal DataFrame"

    # NOTE: It's assumed that `all_labels` is a collection of lists
    all_labels = df[label_col].values
    all_labels = flatten(all_labels)

    return pd.Series(all_labels).value_counts().sort_index()


class LabelsStatsMixin:
    def setup_labels_stats(self):
        self.stats_output_area = widgets.Output()

        self.stats_source_button = widgets.Dropdown(
            options=[
                ("SOURCE: LABEL COLUMN", self.label_col),
                ("SOURCE: METADATA COLUMN", self.metadata_col),
            ],
        )
        self.stats_source_button.add_class(CSS_NAMES.STATS_SOURCE_DROPDOWN)

    def plot_stats(self, df: pd.DataFrame, title: str = ""):
        self.stats_output_area.clear_output()
        with self.stats_output_area:
            vc = compute_label_distribution(
                df=df, label_col=self.stats_source_button.value
            )
            if len(vc) < 10:
                figsize = (10, 5)
            elif len(vc) < 30:
                figsize = (10, 10)
            elif len(vc) < 60:
                figsize = (10, 20)
            else:
                figsize = (10, 30)
            try:
                fig, ax = plt.subplots(figsize=figsize, dpi=100)
                vc.plot(kind="barh", ax=ax)
                ax.set_xlabel("Frequency")
                ax.set_title(
                    f"{title} Distribution [{len(df)} Images; {vc.sum()} Tags]"
                )
                # Force x-axis to integer type
                ax.xaxis.set_major_locator(MaxNLocator(integer=True))

                # Annotate bar with frequency of label
                for i, v in enumerate(vc.tolist()):
                    ax.text(
                        v + 0.02, i - 0.075, str(v), color="#859296", fontweight="bold"
                    )

                display(fig)
                plt.close()
            except:
                self.stats_output_area.clear_output()
                print("!! Nothing to plot !!")
                plt.close()

    def generate_refresh_stats_button(self, callbacks=[]) -> List[Button]:
        filt_button = Button(description="⟳ All Filtered Images")
        active_button = Button(description="⟳ Main Grid Images")
        review_button = Button(description="⟳ Review Images")
        total_button = Button(description="⟳ Full Dataset Images")
        selected_button = Button(description="⟳ Selected Images")

        total_button.on_click(
            lambda x: self.plot_stats(
                df=self.df,
                title="Total Images",
            )
        )
        filt_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(self.class_map_subset_filter),
                title="Filtered Images",
            )
        )
        selected_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(self.selected_names),
                title="Filtered Images",
            )
        )
        active_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(
                    [item.source for item in self.active_datapoints]
                ),
                title="Active (Viewable) Images",
            )
        )
        review_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(
                    [item.source for item in self.review_datapoints]
                ),
                title="Active (Viewable) Images",
            )
        )

        # Add callbacks
        for cb in callbacks:
            filt_button.on_click(cb)
            total_button.on_click(cb)

        active_button.layout.width = "180px"
        filt_button.layout.width = "210px"
        total_button.layout.width = "210px"
        selected_button.layout.width = "180px"
        review_button.layout.width = "180px"

        return total_button, filt_button, selected_button, active_button, review_button

==> datawidgets-0.0.10-py3-none-any.whl: datawidgets/dataset/stats_mixins.py <==
from datawidgets.imports import *
from datawidgets.utils import *
from datawidgets.data import *

# from .base_dataset import *
# from .classification_dataset import *

from matplotlib.ticker import MaxNLocator


def compute_label_distribution(df: pd.DataFrame, label_col="label") -> pd.Series:
    "Computes the frequency of labels from a dataset's internal DataFrame"

    # NOTE: It's assumed that `all_labels` is a collection of lists
    all_labels = df[label_col].values
    all_labels = flatten(all_labels)

    return pd.Series(all_labels).value_counts().sort_index()


class LabelsStatsMixin:
    def setup_labels_stats(self):
        self.stats_output_area = widgets.Output()

        self.stats_source_button = widgets.Dropdown(
            options=[
                ("SOURCE: LABEL COLUMN", self.label_col),
                ("SOURCE: METADATA COLUMN", self.metadata_col),
            ],
        )
        self.stats_source_button.add_class(CSS_NAMES.STATS_SOURCE_DROPDOWN)

    def plot_stats(self, df: pd.DataFrame, title: str = ""):
        self.stats_output_area.clear_output()
        with self.stats_output_area:
            vc = compute_label_distribution(
                df=df, label_col=self.stats_source_button.value
            )
            if len(vc) < 10:
                figsize = (10, 5)
            elif len(vc) < 30:
                figsize = (10, 10)
            elif len(vc) < 60:
                figsize = (10, 20)
            else:
                figsize = (10, 30)
            try:
                fig, ax = plt.subplots(figsize=figsize, dpi=100)
                vc.plot(kind="barh", ax=ax)
                ax.set_xlabel("Frequency")
                ax.set_title(
                    f"{title} Distribution [{len(df)} Images; {vc.sum()} Tags]"
                )
                # Force x-axis to integer type
                ax.xaxis.set_major_locator(MaxNLocator(integer=True))

                # Annotate bar with frequency of label
                for i, v in enumerate(vc.tolist()):
                    ax.text(
                        v + 0.02, i - 0.075, str(v), color="#859296", fontweight="bold"
                    )

                display(fig)
                plt.close()
            except:
                self.stats_output_area.clear_output()
                print("!! Nothing to plot !!")
                plt.close()

    def generate_refresh_stats_button(self, callbacks=[]) -> List[Button]:
        filt_button = Button(description="⟳ All Filtered Images")
        active_button = Button(description="⟳ Main Grid Images")
        review_button = Button(description="⟳ Review Images")
        total_button = Button(description="⟳ Full Dataset Images")
        selected_button = Button(description="⟳ Selected Images")

        total_button.on_click(
            lambda x: self.plot_stats(
                df=self.df,
                title="Total Images",
            )
        )
        filt_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(self.class_map_subset_filter),
                title="Filtered Images",
            )
        )
        selected_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset(self.selected_ids),
                title="Selected Images",
            )
        )
        active_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset([item.id for item in self.active_datapoints]),
                title="Active (Viewable) Images",
            )
        )
        review_button.on_click(
            lambda x: self.plot_stats(
                df=self.filter_dataset([item.id for item in self.review_datapoints]),
                title="Review (Viewable) Images",
            )
        )

        # Add callbacks
        for cb in callbacks:
            filt_button.on_click(cb)
            total_button.on_click(cb)

        active_button.layout.width = "180px"
        filt_button.layout.width = "210px"
        total_button.layout.width = "210px"
        selected_button.layout.width = "180px"
        review_button.layout.width = "180px"

        return total_button, filt_button, selected_button, active_button, review_button
